@@ -1,5 +1,5 @@
 from datetime import datetime
-from utils.log_utils import LogUtils as log_utils
+from gdo_arch_utils.utils.log_utils import LogUtils as log_utils
 
 logger = log_utils.get_logger()
 
